'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');


var AngularBootstrapLessGenerator = module.exports = function AngularBootstrapLessGenerator(args, options, config) {
  yeoman.generators.Base.apply(this, arguments);

  this.on('end', function () {
    this.installDependencies({ skipInstall: options['skip-install'] });
  });

  this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(AngularBootstrapLessGenerator, yeoman.generators.Base);

AngularBootstrapLessGenerator.prototype.askFor = function askFor() {
  var cb = this.async();

  // have Yeoman greet the user.
  console.log(this.yeoman);

  var prompts = [{
    name: 'appName',
    message: 'How would you like to name your app?',
	default: 'app-name'
  }];

  this.prompt(prompts, function (props) {
    this.appName = props.appName;

    cb();
  }.bind(this));
};

AngularBootstrapLessGenerator.prototype.app = function app() {
  this.mkdir('img');
  this.mkdir('js');
  this.mkdir('less');
  this.mkdir('partials');

  this.copy('gitkeep', 'img/.gitkeep');
  this.copy('gitkeep', 'partials/.gitkeep');
  
  this.copy('js/_app.js', 'js/app.js');
  this.copy('js/_controllers.js', 'js/controllers.js');
  this.copy('js/_directives.js', 'js/directives.js');
  this.copy('js/_filters.js', 'js/filters.js');
  this.copy('js/_services.js', 'js/services.js');
  
  this.copy('less/_bootstrap.less', 'less/bootstrap.less');
  
  this.copy('gitignore', '.gitignore');
  this.copy('_Gruntfile.js', 'Gruntfile.js');
  this.copy('_bower.json', 'bower.json');
  this.copy('_package.json', 'package.json');  
};

AngularBootstrapLessGenerator.prototype.projectfiles = function projectfiles() {
  
};
